See also open issues tracked for mile-stone web2ldap-1.7

# 1.7.8

Release Date: 2022-07-13

- Fixed BytesWarning when running with -bb and adding entries (fixes #61).

# 1.7.7

Release Date: 2022-03-28

- Fixed plugin class for attribute aAAARecord to correctly display a link for searching accompanying PTR RR entry.
- Quick search field in Æ-DIR's top section is now of `type="search"` .

# 1.7.6

Release Date: 2022-02-21

- Improved section for limits in HTML templates for OpenLDAP's cn=config.
- Added work-around to `setup.py` to let stdeb use `--install-data /` (fixes #43).
- Moved link "My connections" to main area (fixes #56).
- The constant-time string comparison function hmac.compare_digest() is now used for validating session cookie value to prevent timing attacks (fixes #57).

# 1.7.5

Release Date: 2022-02-12

- Added attribute olcLimits to HTML templates for OpenLDAP's cn=config (implements #53).
- Register attribute olcLimits for use with plugin class OlcMultilineText.
- Fixed str/bytes regression in Æ-DIR plugin class for attribute homeDirectory (fixes #54).

# 1.7.3

Release Date: 2022-02-11

- For now module h2 is strictly blocked from being imported (via dnspython) because it is currently not useful herein, seriously broken, and thus does not run with Python's command-line option `-bb` (see h2#1236).
- Added plugin class for MS Exchange attribute msExchRecipientTypeDetails based on plugin class BitArrayInteger.
- Success message after changing group membership also shows member's DN.

# 1.7.2

Release Date: 2022-02-07

- If search parameter filterstr is provided along with a single search_string but without search_attr it is assumed to be a Python string template for forming the filter.
  This is used to enhance the quick search field in Æ-DIR's top section (implements #50).
- Added missing semicolon to HTML character entity names.

# 1.7.1

Release Date: 2022-02-05

- Added appropriate autocomplete attribute to input fields in login and change password forms (implements #49).
- Added missing semicolon to HTML character entity names.

# 1.7.0

Release Date: 2022-01-29

## Installation and configuration changes

- Requires update of module ldap0.
- Requires installation of module iso3166 (see also issue #46).
- Optional installation of module package phonenumbers.

## New features/enhancements

- Added session ID in URL to cookie path.
- Added some more specific plugin registrations for these attributes:
  - thumbnailPhoto (on MS AD) registered with syntax class Binary
  - olcPPolicyDefault (in OpenLDAP's cn=config) registered with syntax class DistinguishedName
- Optional use of module package phonenumbers to sanitize input values of LDAP syntax TelephoneNumber (implements #4).
- Cleaned out confusing texts from top section, especially when not connected.
- Re-factored CSS for top section to have less contrasting back-ground colors.
- Added HTML input templates and basic plugin classes for PowerDNS schema for master mode (implements #38).

## Bug fixes

- Avoid to decode the whole entry of all search results when building list of mail addresses for Cc: and Bcc: links. This fixes UnicodeDecodeError in case some of the attributes are not Unicode (UTF-8) (fixes #41).
- Avoid floating of displayed images on the right in read entry table (fixes #35).
- Fixed HTML/CSS to correct vertical position of input fields with invalid input value (fixes #48).
- Fixed HTML to correct vertical position of expanded sub-trees in DIT browser.